@@ -20,6 +20,15 @@
 #include "DataInput.h"
 
 #include <Lum/Base/L10N.h>
+#include <Lum/Base/String.h>
+
+#include <Lum/Dlg/Msg.h>
+#include <Lum/Dlg/Values.h>
+
+#include <Lum/Model/Header.h>
+#include <Lum/Model/String.h>
+
+#include <Lum/OS/Theme.h>
 
 #include <Lum/Array.h>
 #include <Lum/Button.h>
@@ -32,14 +41,6 @@
 #include <Lum/TextValue.h>
 #include <Lum/TimeSelect.h>
 
-#include <Lum/Base/String.h>
-
-#include <Lum/Dlg/Msg.h>
-#include <Lum/Dlg/Values.h>
-
-#include <Lum/Model/Header.h>
-#include <Lum/Model/String.h>
-
 #include "Configuration.h"
 #include "Trend.h"
 #include "Util.h"
@@ -239,7 +240,6 @@ DataInput::DataInput()
    todayAction(new Lum::Model::Action()),
    nextDayAction(new Lum::Model::Action()),
 
-   //addFoodAction(new Lum::Model::Action()),
    addWeightAction(new Lum::Model::Action()),
    removeItemAction(new Lum::Model::Action()),
    editItemAction(new Lum::Model::Action()),
@@ -259,11 +259,12 @@ DataInput::DataInput()
   Observe(todayAction);
   Observe(nextDayAction);
 
-  //Observe(addFoodAction);
   Observe(addWeightAction);
   Observe(removeItemAction);
   Observe(editItemAction);
 
+  Observe(entrySelection);
+
   Observe(trendType);
   Observe(trendDirection);
   Observe(refValue);
@@ -312,17 +313,16 @@ void DataInput::CalcSize()
   text->SetMinWidth(Lum::Base::Size::stdCharWidth,9);
   ds->Add(text);
 
-  ds->AddSpace(true);
-  /*
-  button=new Lum::Button(L"+F");
-  button->SetModel(addFoodAction);
-  ds->Add(button);
-
-  ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));*/
-
-  ds->Add(Lum::Button::Create(L"+",addWeightAction));
-  ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));
-  ds->Add(Lum::Button::Create(L"-",removeItemAction));
+  ds->AddSpace(true)
+    ->Add(Lum::Button::Create(L"+",
+                              Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::addStockImage),
+                              addWeightAction,
+                              Lum::Button::typeIcon))
+    ->Add(new Lum::HSpace(Lum::Space::sizeSmall))
+    ->Add(Lum::Button::Create(L"-",
+                              Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::removeStockImage),
+                              removeItemAction,
+                              Lum::Button::typeIcon));
 
   // Entries table
 
@@ -374,6 +374,9 @@ void DataInput::UpdateEntries()
     return;
   }
 
+  editItemAction->Disable();
+  removeItemAction->Disable();
+
   entries->Clear();
 
   // Entries
@@ -696,6 +699,16 @@ void DataInput::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
   else if (model==trendType || model==trendDirection || model==refValue) {
     UpdateSummary();
   }
+  else if (model==entrySelection) {
+    if (entrySelection->HasSelection()) {
+      editItemAction->Enable();
+      removeItemAction->Enable();
+    }
+    else {
+      editItemAction->Disable();
+      removeItemAction->Disable();
+    }
+  }
 
   Lum::Component::Resync(model,msg);
 }
