@@ -558,7 +558,7 @@ bool Diagram::HandleMouseEvent(const Lum::OS::MouseEvent& event)
       }
     }
 
-    Draw(oX,oY,oWidth,oHeight);
+    Redraw();
   }
   else if (event.type==Lum::OS::MouseEvent::down &&
      PointIsIn(event) &&
@@ -570,7 +570,7 @@ bool Diagram::HandleMouseEvent(const Lum::OS::MouseEvent& event)
      mode=(Mode)((mode-1)%(modeMax+1));
    }
 
-   Draw(oX,oY,oWidth,oHeight);
+   Redraw();
 
    return true;
   }
@@ -579,7 +579,7 @@ bool Diagram::HandleMouseEvent(const Lum::OS::MouseEvent& event)
           event.button==Lum::OS::MouseEvent::button5) {
    mode=(Mode)((mode+1)%(modeMax+1));
 
-   Draw(oX,oY,oWidth,oHeight);
+   Redraw();
 
    return true;
   }
