@@ -27,6 +27,7 @@
 #include <Lum/DateSelect.h>
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
+#include <Lum/Space.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
 #include <Lum/TimeSelect.h>
@@ -39,6 +40,8 @@
 #include <Lum/Model/Header.h>
 #include <Lum/Model/String.h>
 
+#include <Lum/OS/Theme.h>
+
 #include "Configuration.h"
 #include "Trend.h"
 #include "Util.h"
@@ -253,7 +256,8 @@ public:
 };
 
 FoodInput::FoodInput()
- : addFoodEntryAction(new Lum::Model::Action()),
+ : clearFilterAction(new Lum::Model::Action()),
+   addFoodEntryAction(new Lum::Model::Action()),
    removeFoodEntryAction(new Lum::Model::Action()),
    editFoodEntryAction(new Lum::Model::Action()),
    registerFoodAction(new Lum::Model::Action()),
@@ -265,12 +269,15 @@ FoodInput::FoodInput()
    searchTimerAction(new Lum::Model::Action())
 {
   Observe(foodSearch);
+  Observe(clearFilterAction);
 
   Observe(addFoodEntryAction);
   Observe(removeFoodEntryAction);
   Observe(editFoodEntryAction);
   Observe(registerFoodAction);
 
+  Observe(foodSelection);
+
   Observe(searchTimerAction);
 
   Observe(goodValueLimit);
@@ -290,7 +297,32 @@ void FoodInput::CalcSize()
   // Search box
 
   sb=Lum::VPanel::Create(true,false);
-  sb->Add(Lum::String::Create(foodSearch,true,false));
+  sb->Add(Lum::HPanel::Create(true,false)
+          ->Add(Lum::Text::Create(L"Search:"))
+          ->AddSpace()
+          ->Add(Lum::String::Create(foodSearch,true,false))
+          ->Add(Lum::Button::Create(L"_Clear",clearFilterAction,false,true))
+          ->AddSpace()
+          ->Add(Lum::Button::Create(L"+",
+                                    Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::addStockImage),
+                                    addFoodEntryAction,
+                                    Lum::Button::typeIcon))
+          ->Add(new Lum::HSpace(Lum::Space::sizeSmall))
+          ->Add(Lum::Button::Create(L"-",
+                                    Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::removeStockImage),
+                                    removeFoodEntryAction,
+                                    Lum::Button::typeIcon))
+          ->Add(new Lum::HSpace(Lum::Space::sizeSmall))
+          ->Add(Lum::Button::Create(L"~",
+                                    Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::editStockImage),
+                                    editFoodEntryAction,
+                                    Lum::Button::typeIcon))
+          ->Add(new Lum::HSpace(Lum::Space::sizeSmall))
+          ->Add(Lum::Button::Create(L"->",
+                                    Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::positiveStockImage),
+                                    registerFoodAction,
+                                    Lum::Button::typeIcon))
+          );
 
   // Food table
 
@@ -338,6 +370,10 @@ void FoodInput::CalcSize()
 
 void FoodInput::UpdateFoods()
 {
+  editFoodEntryAction->Disable();
+  removeFoodEntryAction->Disable();
+  registerFoodAction->Disable();
+
   std::wstring filter=foodSearch->Get();
 
   Lum::Base::ToLower(filter);
@@ -537,7 +573,12 @@ void FoodInput::RegisterFood()
 
 void FoodInput::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
 {
-  if (model==addFoodEntryAction && addFoodEntryAction->IsFinished()) {
+  if (model==clearFilterAction && clearFilterAction->IsFinished()) {
+    lastFoodSearchFilter=foodSearch->Get();
+    foodSearch->Set(L"");
+    UpdateFoods();
+  }
+  else if (model==addFoodEntryAction && addFoodEntryAction->IsFinished()) {
     AddFoodEntry();
   }
   else if (model==editFoodEntryAction && editFoodEntryAction->IsFinished()) {
@@ -563,12 +604,23 @@ void FoodInput::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
     Lum::OS::display->AddTimer(1,500000,searchTimerAction);
   }
   else if (model==searchTimerAction && searchTimerAction->IsFinished()) {
-
     if (foodSearch->Get()!=lastFoodSearchFilter) {
       UpdateFoods();
       lastFoodSearchFilter=foodSearch->Get();
     }
   }
+  else if (model==foodSelection) {
+    if (foodSelection->HasSelection()) {
+      editFoodEntryAction->Enable();
+      removeFoodEntryAction->Enable();
+      registerFoodAction->Enable();
+    }
+    else {
+      editFoodEntryAction->Disable();
+      removeFoodEntryAction->Disable();
+      registerFoodAction->Disable();
+    }
+  }
 
   Lum::Component::Resync(model,msg);
 }
