@@ -25,7 +25,6 @@
 #include <Lum/ButtonRow.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 
 #include "Configuration.h"
 #include "Util.h"
@@ -42,8 +41,6 @@ Statistics::~Statistics()
 
 void Statistics::PreInit()
 {
-  Lum::Button      *button;
-  Lum::ButtonRow   *buttonRow;
   Lum::Label       *label;
   Lum::Panel       *panel;
 
@@ -108,20 +105,8 @@ void Statistics::PreInit()
   label->AddLabel(_(L"STAT_LABEL_VALUE_MAX",L"Maximum value:"),ValueToString(maxValue)+L" "+valueUnit->Get());
 
   panel->Add(label);
-
-  panel->Add(new Lum::VSpace());
-
-  buttonRow=new Lum::ButtonRow();
-  buttonRow->SetFlex(true,false);
-
-  button=new Lum::Button();
-  button->SetFlex(true,true);
-  button->SetModel(GetClosedAction());
-  button->SetType(Lum::Button::typeDefault);
-  button->SetText(_ld(dlgButtonClose));
-  buttonRow->Add(button);
-
-  panel->Add(buttonRow);
+  panel->AddSpace();
+  panel->Add(Lum::ButtonRow::CreateClose(GetClosedAction(),true,false));
 
   SetMain(panel);
 
